<?php

namespace Litecms\GoogleCaptcha\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\GoogleCaptcha\Models\GoogleCaptchaKey;

class GoogleCaptchaKeyPolicy
{

    /**
     * Determine if the given user can view the google_captcha_key.
     *
     * @param UserPolicy $user
     * @param GoogleCaptchaKey $google_captcha_key
     *
     * @return bool
     */
    public function view(UserPolicy $user, GoogleCaptchaKey $google_captcha_key)
    {
        if ($user->canDo('google_captcha.google_captcha_key.view') && $user->isAdmin()) {
            return true;
        }

        return $google_captcha_key->user_id == user_id() && $google_captcha_key->user_type == user_type();
    }

    /**
     * Determine if the given user can create a google_captcha_key.
     *
     * @param UserPolicy $user
     * @param GoogleCaptchaKey $google_captcha_key
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('google_captcha.google_captcha_key.create');
    }

    /**
     * Determine if the given user can update the given google_captcha_key.
     *
     * @param UserPolicy $user
     * @param GoogleCaptchaKey $google_captcha_key
     *
     * @return bool
     */
    public function update(UserPolicy $user, GoogleCaptchaKey $google_captcha_key)
    {
        if ($user->canDo('google_captcha.google_captcha_key.edit') && $user->isAdmin()) {
            return true;
        }

        return $google_captcha_key->user_id == user_id() && $google_captcha_key->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given google_captcha_key.
     *
     * @param UserPolicy $user
     * @param GoogleCaptchaKey $google_captcha_key
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, GoogleCaptchaKey $google_captcha_key)
    {
        return $google_captcha_key->user_id == user_id() && $google_captcha_key->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given google_captcha_key.
     *
     * @param UserPolicy $user
     * @param GoogleCaptchaKey $google_captcha_key
     *
     * @return bool
     */
    public function verify(UserPolicy $user, GoogleCaptchaKey $google_captcha_key)
    {
        if ($user->canDo('google_captcha.google_captcha_key.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given google_captcha_key.
     *
     * @param UserPolicy $user
     * @param GoogleCaptchaKey $google_captcha_key
     *
     * @return bool
     */
    public function approve(UserPolicy $user, GoogleCaptchaKey $google_captcha_key)
    {
        if ($user->canDo('google_captcha.google_captcha_key.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
