<?php

namespace Litecms\GoogleCaptcha\Providers;

use Illuminate\Support\ServiceProvider;

class GoogleCaptchaServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'google_captcha');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'google_captcha');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerGoogleCaptcha();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerGoogleCaptcha()
    {
        $this->app->bind('google_captcha', function($app) {
            return new GoogleCaptcha($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('GoogleCaptcha', 'Lavalite\GoogleCaptcha\Facades\GoogleCaptcha');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('litecms.google_captcha', function ($app) {
            return $this->app->make('Litecms\GoogleCaptcha\GoogleCaptcha');
        });

                // Bind GoogleCaptchaKey to repository
        $this->app->bind(
            'Litecms\GoogleCaptcha\Interfaces\GoogleCaptchaKeyRepositoryInterface',
            \Litecms\GoogleCaptcha\Repositories\Eloquent\GoogleCaptchaKeyRepository::class
        );

        $this->app->register(\Litecms\GoogleCaptcha\Providers\AuthServiceProvider::class);
                $this->app->register(\Litecms\GoogleCaptcha\Providers\EventServiceProvider::class);
        
        $this->app->register(\Litecms\GoogleCaptcha\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and google_captcha's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/google_captcha.php', 'google_captcha'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeGoogleCaptcha::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.google_captcha'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/google_captcha.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/google_captcha')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/google_captcha')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
